pub enum DataStorage {
Ascii,
AsciiInline,
Hdf5SingleFile {
deflate_level: Option<u8>,
},
Hdf5MultipleFiles {
deflate_level: Option<u8>,
},
Binary,
}Expand description
Type of storage used for the heavy data (e.g. ASCII or HDF5)
Variants
Ascii
store the data in ASCII format, each set of data is stored in a separate file.
AsciiInline
store the data in ASCII format, but inline in the XDMF file. This is only recommended for small datasets.
Hdf5SingleFile
store the data in HDF5 format, all data in a single HDF5 file.
Fields
Hdf5MultipleFiles
store the data in HDF5 format, one file per time step.
Fields
Binary
store the data in uncompressed raw binary format, each set of data is stored in a separate file.